'''
flickrcc.py
Flickr and Creative Commons License enforcement

Requires flickrlib.py (http://monotonous.org/2005/11/26/flickrlib-05/)

Author: oshani@mit.edu
Date: Aug 26th, 2008
'''

#!/usr/local/bin/python

from flickrlib import FlickrAgent
import re

#Do not touch these!
api_key = '2a578583bde85008e9ffd8226fa25a82'
api_secret = '034e8f97117b8c37'
FLICKR_LICENSES = (
    ('0', 'All Rights Reserved'),
    ('1', 'Attribution-NonCommercial-ShareAlike License'),
    ('2', 'Attribution-NonCommercial License'),
    ('3', 'Attribution-NonCommercial-NoDerivs License'),
    ('4', 'Attribution License'),
    ('5', 'Attribution-ShareAlike License'),
    ('6', 'Attribution-NoDerivs License'),
)

def check_cc_license(photo_info):
    ''' Parse the JSON string and determine if it has some form of CC License attached with it. If the License type is not == 0, that means you would have to attribute it '''
    license =  photo_info['license']
    if license == '0':
        return False # attribution NOT NEEDED
    else:
        return True # attribution NEEDED
    
def find_creator(photo_info):
    ''' Check to which user this photo belongs to and construct the flickr user URI '''
    return "http://www.flickr.com/photos/"+ photo_info['owner'][0]['nsid']
    
def get_photo_info(photo_id):
    '''Extract the photo infor once the id is known'''
    agent = FlickrAgent(api_key, api_secret)
    photo_info = agent.flickr.photos.getInfo(photo_id=photo_id)
    return photo_info

def extract_photo_id(photo_uri):
    ''' This function will extract the photo id given a URI like
    http://farm3.static.flickr.com/2132/2183778686_a8e7b565c3.jpg 
    According to the documentation at http://flickr.com/services/api/misc.urls.html, the above URL is basically:
    http://farm{farm-id}.static.flickr.com/{server-id}/{id}_{secret}.jpg
	or
        http://farm{farm-id}.static.flickr.com/{server-id}/{id}_{secret}_[mstb].jpg
	or
        http://farm{farm-id}.static.flickr.com/{server-id}/{id}_{o-secret}_o.(jpg|gif|png)'''
    p = re.compile('\d+\_')
    q = re.compile('\d+')
    r = p.findall(photo_uri)
    if len(r) != 1:
        print "Something wrong with the Flickr URI!"
        return None
    else:
        s = q.findall(r[0])
        return s
    
if __name__ == '__main__':
    uri = 'http://farm3.static.flickr.com/2132/2183778686_a8e7b565c3.jpg'
    photo_id = extract_photo_id(uri)[0]
    photo_info = get_photo_info(photo_id)
    print find_creator(photo_info)
