'''
spider.py
Breadth First Traversal to find links which have a valid flickr images embedded in it.
Code modifed from the spider example at: http://www.ibm.com/developerworks/linux/library/l-spider/

Date: Aug 26th, 2008
'''

#!/usr/local/bin/python

import httplib
import sys
import re
from HTMLParser import HTMLParser
from qdos import *
from flickrcc import *


class miniHTMLParser( HTMLParser ):

  viewedQueue = []
  instQueue = []
  imageQueue = []

  def get_next_link( self ):
    if self.instQueue == []:
      return ''
    else:
      return self.instQueue.pop(0)


  def gethtmlfile( self, site, page ):
    try:
      httpconn = httplib.HTTPConnection(site)
      httpconn.request("GET", page)
      resp = httpconn.getresponse()
      resppage = resp.read()
    except:
      resppage = ""

    return resppage


  def handle_starttag( self, tag, attrs ):

    if tag == 'img' or tag == 'a':
      newstr = str(attrs[0][1])
      #Check if the uri is a proper static Flickr URI
      if re.search('http://farm\d.static.flickr.com', newstr) != None:
        #print "  adding", newstr
        self.imageQueue.append( newstr )
        
def crawl(site, link):

  mySpider = miniHTMLParser()

  while link != '':

    # Get the file from the site and link
    retfile = mySpider.gethtmlfile( site, link )

    # Feed the file into the HTML parser
    mySpider.feed(retfile)

    # Search the retfile here

    # Get the next link in level traversal order
    link = mySpider.get_next_link()

  while len(mySpider.imageQueue) > 0:
    photo_id =  extract_photo_id(mySpider.imageQueue.pop())[0]
    
    #image found, so check whether the original creator has been attributed anywhere in the document using the FOAF URI and the Name
    photo_info = get_photo_info(photo_id)
    
    creator = find_creator(photo_info)
    
    foaf = None
    name = None 
    foaf_list = find_foaf(creator)
    if len(foaf_list) >0 : foaf =foaf_list.pop()
    name_list = find_name(creator)
    if len(name_list) > 0: name = name_list.pop()
    
    if (name != None):
      print "\n* Checking photo ", photo_id, "by " + name +" with Creative Commons", FLICKR_LICENSES[int(photo_info['license'])][1], "..."
      if check_cc_license(photo_info): #Attribution Needed
        if re.search(foaf,retfile) != None:
          print "\tFOAF URI '", foaf, "'found in blog => Attribution has been Given"
        elif re.search(name, retfile) != None:
          print "\tName '", name, "' found in blog => Attribution has been Given"
        else:
          print "\tFOAF URI or Name NOT found in blog => Attribution has NOT been given"
      else:
        print "\tAttribution NOT needed for this photo!"

        
  mySpider.close()


if __name__ == "__main__":
  site = 'oshanis.blogspot.com'
  link = '/'
  crawl(site, link)
